@@ -66,7 +66,9 @@ def version(module):
 
 
 class CheckCmd:
+    @parse_args()
     def do_check(self, args):
+        """Experimental."""
         import climetlab
 
         print(
@@ -282,4 +284,8 @@ class CheckCmd:
     def do_df(self, path):
         from climetlab.core.caching import disk_usage
 
+        if path == "-h":
+            print("Provide some information about disk usage.")
+            return
+
         print(disk_usage(path))
